define([
    'jquery'
], function ($) {
    'use strict';

    return function (target) {
        return target.extend({
            /**
             * Set shipping information
             */
            setShippingInformation: function () {
                var self = this;
                
                // Ensure address is properly set before placing order
                if (quote.shippingAddress() === null) {
                    this.isVisible(true);
                    return false;
                }

                return this._super();
            }
        });
    };
});
